yakumo.cinder.v1.volume.Manager

Package yakumo :: Package cinder :: Package v1 :: Module volume :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

manager class for roles on Block Storage V1 API

Nested Classes | [hide private]
| resource_class resource class for volumes on Block Storage V1 API

Instance Methods | [hide private]
_attr2json(self, attrs) | source code
_json2attr(self, json_params) | source code
yakumo.base.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, size=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`, source=`'``__UNDEF__``'`, volume_type=`'``__UNDEF__``'`, metadata=`'``__UNDEF__``'`) Create a volume | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_find_gen`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``volume``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``volume``'``
| _json_resources_key = ``'``volumes``'``
| _hidden_methods = ``[``'``update``'``]``
| _url_resource_list_path = ``'``/volumes/detail``'``
| _url_resource_path = ``'``/volumes``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### _attr2json(self, attrs) | source code
Overrides: base.Manager._attr2json

### _json2attr(self, json_params) | source code
Overrides: base.Manager._json2attr

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, size=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, availability_zone=`'``__UNDEF__``'`, source=`'``__UNDEF__``'`, volume_type=`'``__UNDEF__``'`, metadata=`'``__UNDEF__``'`) | source code
Create a volume Parameters: `name` (str) - Volume name `description` (str) - Description `size` (int) - Size in GB `project` (yakumo.project.Resource) - Project `availability_zone` (yakumo.availability_zone.Resource) - Availability zone `source` (one of yakumo.image.Resource, yakumo.volume_snapshot.Resource and yakumo.volume.Resource) - Source image/snapshot/volume (optional) `volume_type` (yakumo.cinder.v1.volume_type.Resource) - Volume type `metadata` (dict) - Metadata (key=value) Returns: yakumo.base.Resource Created volume Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'display_name', mapper.Noop), ('d
      escription', 'display_description', mapper.Noop), ('availability_zone'
      , 'availability_zone', mapper.Noop), ('size', 'size', mapper.Noop), ('
      status', 'status', mapper.Noop), ('attachments', 'attachments', mapper
      .Noop), ('volume_type', 'volume_type', mapper.Resource('cinder.volume_
      type')), ('source_image', 'imageRef', mapper.Resource('image')), ('sou
      rce_snapshot', 'snapshot_id', mapper.Resource('cinder.volume_snapshot'
      )), ('source_volume', 'source_volid', mapper.Resource('cinder.volume')
      ...